pub struct GenomePosition {
pub reference: char,
pub is_deleted: bool,
pub is_deleted_minor: bool,
pub deleted_evidence: Vec<Evidence>,
pub alts: Vec<Alt>,
pub genome_idx: i64,
pub genes: Vec<String>,
}Expand description
Struct to hold the information of a genome position
Fields
reference: charNucleotide at this position
is_deleted: boolWhether this position has been deleted
is_deleted_minor: boolWhether this position has been deleted in a minor allele
deleted_evidence: Vec<Evidence>Added for evidence of a deletion which didn’t start at this position but affects it Includes evidence of minor deletions for simplicity
alts: Vec<Alt>Used to store calls from VCF
genome_idx: i641-indexed genome index
genes: Vec<String>Names of genes present at this position