pub fn parse_genbank_location(
location: &Location,
ranges: &mut Vec<(i64, i64)>,
reverse_complement: bool,
) -> boolExpand description
Recursively parse a GenBank location into ranges Required as complement and join can be nested
Arguments
location- GenBank location to parseranges- Mutable vector to store the parsed rangesreverse_complement- Whether the location is on the reverse complement strand. Should be false at the top level.
Returns
Whether the location is on the reverse complement strand